@@ -55,7 +55,7 @@ BOT = None
 class CLIBot:
     """ Conversation manager intended to interact with the user on the command line, but can be used by other plugins/
 
-    >>> CLIBot(bots='parul,pattern'.split(','), num_top_replies=1).reply('Hi')
+    >>> CLIBot(bots='parul,pattern'.split(','), num_top_replies=1).reply('Hi')[1]
     'Hello!'
     """
     bot_names = []
@@ -157,7 +157,7 @@ class CLIBot:
 
             for i, threshold in enumerate(conf_sums):
                 if roll < threshold:
-                    reply = replies[i][1]
+                    reply = replies[i]
                     self.log_reply(statement, replies[i][0])
                     return reply
             log.error(f"Error rolling dice to select reply."
@@ -165,7 +165,7 @@ class CLIBot:
                       f"\n    threshold: {threshold}"
                       f"\n    conf_sums: {conf_sums}\n"
                       f"\n    replies: {pd.DataFrame(replies)}")
-            return replies[0][1]
+            return replies[0]
         else:
             log.error(f"No replies ({replies}) were returned by {self.bots}!!")
 
@@ -208,13 +208,10 @@ def cli(args,
         if user_statement is None:
             bot_statement = None
         else:
-            bot_statement = BOT.reply(user_statement)
+            bot_statement_tuple = BOT.reply(user_statement)
+        bot_statement = bot_statement_tuple[1]
         history[-1]['bot'] = bot_statement
-        if bot_statement is None:
-            pass
-            # print()
-            # print(f"{args.nickname}: Hi! I'm **{args.nickname}**. Ask me anything!")
-        else:
+        if bot_statement is not None:
             print(f'{args.nickname}: ')
             print(bot_statement)
         if max_turns > 0 or not user_statement:
