@@ -1,4 +1,4 @@
-from collections import Counter, OrderedDict, Mapping
+from collections import Counter, OrderedDict, Mapping, namedtuple
 from decimal import Decimal
 import datetime
 import logging
@@ -20,7 +20,10 @@ import django.conf
 
 from qary import __version__
 
-# DO ACCESS KEY and SECRET need to be integrated into env
+# tuple to hold score, text, and bot-name
+BotReply = namedtuple('BotReply', ['confidence', 'text', 'skill'], defaults=[None] * 3)  # noqa
+
+# TODO: Do Django ACCESS_KEY and SECRET need to be integrated into env ?
 env = Environment(spacy_lang=str, loglevel=int, name=str)
 # if you need consistent hashes from builtin hash function set env['PYTHONHASHSEED']
 
