@@ -2,7 +2,7 @@
 import pytest  # noqa
 import pandas as pd
 
-from qary.skills.qa_bots import Bot
+from qary.skills.qa import Skill
 from qary.qa.qa_datasets import get_bot_accuracies
 
 import logging
@@ -16,17 +16,17 @@ __license__ = "The Hippocratic License, see LICENSE.txt (MIT + Do no Harm)"
 
 
 def test_qa_bots():
-    bot = Bot()
+    bot = Skill()
     assert callable(bot.reply)
     replies = bot.reply('Hi', context='')
     assert len(replies) == 0
     obama_replies = bot.reply(
         'When was Obama born?',
-        context={'doc': {'text': 'Barack Obama was born in 1967.'}})
+        context={'doc': {'text': 'Barack Obama was born in 1961.'}})
     assert len(obama_replies) > 0
     obama_replies = sorted(obama_replies)
     assert obama_replies[-1][0] > .9
-    assert float(obama_replies[-1][1]) == 1967
+    assert float(obama_replies[-1][1]) == 1961
     obama_replies = bot.reply(
         'Where was Barack born?',
         context='Barack Obama was born in Hawaii. O. was born in Uzbekistan. M. was born in Ukraine.')
@@ -37,7 +37,7 @@ def test_qa_bots():
 
 
 def test_qa_bot_accuracy():
-    bot = Bot()
+    bot = Skill()
     df = pd.DataFrame(get_bot_accuracies(bot))
     q_accuracies = df.groupby('question')['bot_accuracy'].max()
     mean_acc = q_accuracies.mean()
